# Nanosaur pkg

This python package install, manage and control your nanosaur robot.

## Develop

Install this package in develop mode

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -e .
```

Test this package

```console
nanosaur info
```
